@@ -1,3 +1,7 @@
+#if defined(__clang__) && !defined(__OBJC_RUNTIME_INTERNAL__)
+#pragma clang system_header
+#endif
+
 
 #ifdef STRICT_MACOS_X
 #	define OBJC_NONPORTABLE __attribute__((error("Function not supported by the Apple runtime")))
